@@ -13,13 +13,13 @@ class Consumer:
     queue consumer with a general handler to handle posted messages
     """
     def __init__(self, name:str) -> None:
-        self._queue_name = Setting.get('QUEUE', name.upper(), None)
+        self._queue_name = Setting.QUEUE.get(name.upper(), None)
         if self._queue_name is None:
             raise Exception('Queue not found in configuration file, please review!')
 
         self._name = name
-        self._host = Setting.get('AMQP', 'HOST')
-        self._heartbeat = Setting.get_bool('AMQP', 'HEARTBEAT')
+        self._host = Setting.AMQP_HOST
+        self._heartbeat = Setting.HEARTBEAT
         self._handlers = {}
 
     def register(self, handler:Any) -> bool:
