@@ -16,18 +16,39 @@ class Stub:
             content=content
         )
 
+class ExampleStub(Stub):
+    def __init__(self):
+        super().__init__(
+            destination='example'
+        )
+
+    def primitive_one(self) -> None:
+        self._send(
+            primitive='primitive_one',  
+            content={
+                'hello': 'word'
+            }
+        )
+
+    def primitive_two(self, message:str) -> None:
+        self._send(
+            primitive='primitive_two',  
+            content={
+                'message': message
+            }
+        )
+
 class DetectionStub(Stub):
     def __init__(self):
         super().__init__(
             destination='detection_model'
         )
 
-    def find_objects(self, camera_hash:str, image_hash:str, image:np.ndarray) -> None:
+    def find_objects(self, image_id:str, image:np.ndarray) -> None:
         self._send(
             primitive='find_objects',  
             content={
-                'camera_hash': camera_hash,
-                'image_hash': image_hash,
+                'image_id': image_id,
                 'image': image
             }
         )
